==> haskell-text-printer-0.5.0.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-printer
version: 0.5.0.1
id: text-printer-0.5.0.1-BG33voC2AwgIsQ8qW3GjJY
key: text-printer-0.5.0.1-BG33voC2AwgIsQ8qW3GjJY
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/text-printer
synopsis: Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.
category: Text
abi: fdabfb84d9ac1f4ba235394149df17bd
exposed: True
exposed-modules:
    Text.Printer Text.Printer.Fractional Text.Printer.Integral
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-printer-0.5.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-printer-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-printer-0.5.0.1
hs-libraries: HStext-printer-0.5.0.1-BG33voC2AwgIsQ8qW3GjJY
depends:
    base-4.12.0.0 bytestring-0.10.8.2 pretty-1.1.3.6 text-1.2.3.1
    text-latin1-0.3.1-F9gMENqLhQUKEeqgV2t8rB
haddock-interfaces: /usr/share/doc/haskell-text-printer/html/text-printer.haddock
haddock-html: /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-printer-0.5-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-printer
version: 0.5
id: text-printer-0.5-EEnxSm7ih2F3Cat1XqaxzY
key: text-printer-0.5-EEnxSm7ih2F3Cat1XqaxzY
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/text-printer
synopsis: Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.
category: Text
abi: b68ea0e165a2af705e0291c5b8e13ce2
exposed: True
exposed-modules:
    Text.Printer Text.Printer.Fractional Text.Printer.Integral
import-dirs: /usr/lib/ghc-8.6.4/site-local/text-printer-0.5
library-dirs: /usr/lib/ghc-8.6.4/site-local/text-printer-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/text-printer-0.5
hs-libraries: HStext-printer-0.5-EEnxSm7ih2F3Cat1XqaxzY
depends:
    base-4.12.0.0 bytestring-0.10.8.2 pretty-1.1.3.6 text-1.2.3.1
    text-latin1-0.3.1-9Jk52ccaV4CGspJYZunZZU
haddock-interfaces: /usr/share/doc/haskell-text-printer/html/text-printer.haddock
haddock-html: /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
